@@ -1,7 +1,7 @@
 /**
  * @fileoverview Contains all Jabber/XMPP packet related classes.
  * @author Stefan Strigler steve@zeank.in-berlin.de
- * @version $Revision: 471 $
+ * @version $Revision: 480 $
  */
 
 var JSJACPACKET_USE_XMLNS = true;
@@ -221,11 +221,14 @@ JSJaCPacket.prototype.getChild = function(name, ns) {
  */
 JSJaCPacket.prototype.getChildVal = function(name, ns) {
   var node = this.getChild(name, ns);
-  if (node && node.firstChild) {
-    return node.firstChild.nodeValue;
-  } else {
-    return '';
+  var ret = '';
+  if (node && node.hasChildNodes()) {
+    // concatenate all values from childNodes
+    for (var i=0; i<node.childNodes.length; i++)
+      if (node.childNodes.item(i).nodeValue)
+        ret += node.childNodes.item(i).nodeValue;
   }
+  return ret;
 };
 
 /**
@@ -269,18 +272,18 @@ JSJaCPacket.prototype.errorReply = function(stanza_error) {
  * Returns a string representation of the raw xml content of this packet.
  * @type String
  */
-JSJaCPacket.prototype.xml = function() {
-
-  if (this.getDoc().xml) // IE
-    return this.getDoc().xml;
-
-  var xml = (new XMLSerializer()).serializeToString(this.getNode());
-  if (typeof(xml) != 'undefined')
-    return xml;
-  return (new XMLSerializer()).serializeToString(this.doc); // oldschool
-
+JSJaCPacket.prototype.xml = typeof XMLSerializer != 'undefined' ?
+function() {
+  var r = (new XMLSerializer()).serializeToString(this.getNode());
+  if (typeof(r) == 'undefined')
+    r = (new XMLSerializer()).serializeToString(this.doc); // oldschool
+  return r
+} :
+function() {// IE
+  return this.getDoc().xml
 };
 
+
 // PRIVATE METHODS DOWN HERE
 
 /**
@@ -324,8 +327,13 @@ JSJaCPacket.prototype._setChildNode = function(nodeName, nodeValue) {
       aNode.replaceChild(tNode,aNode.firstChild);
     } catch (e) { }
   else {
-    aNode = this.getNode().appendChild(this.getDoc().
-                                       createElement(nodeName));
+    try {
+      aNode = this.getDoc().createElementNS(this.getNode().namespaceURI,
+                                            nodeName);
+    } catch (ex) {
+      aNode = this.getDoc().createElement(nodeName)
+    }
+    this.getNode().appendChild(aNode);
     aNode.appendChild(tNode);
   }
   return aNode;
@@ -372,7 +380,9 @@ JSJaCPacket.prototype.appendNode = function(element) {
   } else { // build node
     return this.getNode().appendChild(this.buildNode(element,
                                                      arguments[1],
-                                                     arguments[2]));
+                                                     arguments[2],
+                                                     null,
+                                                     this.getNode().namespaceURI));
   }
 };
 
